Changelog
=========

0.0.2 (2024-09-25)
------------------

- removed reo-toolkit dependency, as the library is no longer publicly available


0.0.1 (2024-05-02)
------------------

- initial release

